@@ -2,20 +2,18 @@
 ----------------------------------------------------------------------*/
 /**
  * @file		iutest_core_impl_c.h
- * @brief		iris unit test UnitTest  t@C
+ * @brief		iris unit test UnitTest implement
  *
  * @author		t.sirayanagi
- * @version		1.0
- *
  * @par			copyright
- * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 /*----------------------------------------------------------------------
 ======================================================================*/
-#ifndef INCG_IRIS_iutest_core_impl_c_H_D5ABC7DE_C751_4ac0_922F_547880163891_
-#define INCG_IRIS_iutest_core_impl_c_H_D5ABC7DE_C751_4ac0_922F_547880163891_
+#ifndef INCG_IRIS_IUTEST_CORE_IMPL_C_H_D5ABC7DE_C751_4AC0_922F_547880163891_
+#define INCG_IRIS_IUTEST_CORE_IMPL_C_H_D5ABC7DE_C751_4AC0_922F_547880163891_
 
 IUTEST_EXTERN_C_BEGIN()
 
