@@ -1,29 +1,23 @@
-//======================================================================
-//-----------------------------------------------------------------------
+/*======================================================================
+----------------------------------------------------------------------*/
 /**
  * @file		iutest_pragma_c.h
- * @brief		iris unit test pragma ˑ̋z t@C
+ * @brief		iris unit test pragma ˑ̋z
  *
  * @author		t.sirayanagi
- * @version		1.0
- *
  * @par			copyright
- * Copyright (C) 2012, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
-//-----------------------------------------------------------------------
-//======================================================================
-#ifndef INCG_IRIS_iutest_pragma_C_H_FBC5A1DE_3D0C_443e_84B1_5F0618DF9A6B_
-#define INCG_IRIS_iutest_pragma_C_H_FBC5A1DE_3D0C_443e_84B1_5F0618DF9A6B_
+/*----------------------------------------------------------------------
+======================================================================*/
+#ifndef INCG_IRIS_IUTEST_PRAGMA_C_H_FBC5A1DE_3D0C_443E_84B1_5F0618DF9A6B_
+#define INCG_IRIS_IUTEST_PRAGMA_C_H_FBC5A1DE_3D0C_443E_84B1_5F0618DF9A6B_
 
-//======================================================================
-// include
+/* define ============================================================*/
 
-//======================================================================
-// define
-
-// pragma
+/* pragma */
 #if		defined(_MSC_VER)
 #  define IUTEST_PRAGMA(x)	__pragma(x)
 #elif	defined(__GNUC__)
@@ -34,7 +28,13 @@
 #  define IUTEST_PRAGMA(x)
 #endif
 
-// pragma warning
+/* pragma warning */
+#if		defined(_MSC_VER)
+#  define IUTEST_PRAGMA_MSC_WARN_PUSH()			IUTEST_PRAGMA(warning (push))
+#  define IUTEST_PRAGMA_MSC_WARN_DISABLE(x)		IUTEST_PRAGMA(warning (disable: x))
+#  define IUTEST_PRAGMA_MSC_WARN_POP()			IUTEST_PRAGMA(warning (pop))
+#endif
+
 #if		defined(__GNUC__)
 #  if ((__GNUC__ > 4) || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
 #    define IUTEST_PRAGMA_GCC_WARN_PUSH()		IUTEST_PRAGMA(GCC diagnostic push)
@@ -51,28 +51,47 @@
 #  define IUTEST_PRAGMA_CLANG_WARN_PUSH()		IUTEST_PRAGMA(clang diagnostic push)
 #  define IUTEST_PRAGMA_CLANG_WARN_DISABLE(x)	IUTEST_PRAGMA(clang diagnostic ignored x)
 #  define IUTEST_PRAGMA_CLANG_WARN_POP()		IUTEST_PRAGMA(clang diagnostic pop)
+#  ifdef IUTEST_PRAGMA_GCC_WARN_PUSH
+#    undef IUTEST_PRAGMA_GCC_WARN_PUSH
+#  endif
+#  ifdef IUTEST_PRAGMA_GCC_WARN_DISABLE
+#    undef IUTEST_PRAGMA_GCC_WARN_DISABLE
+#  endif
+#  ifdef IUTEST_PRAGMA_GCC_WARN_POP
+#    undef IUTEST_PRAGMA_GCC_WARN_POP
+#  endif
 #  define IUTEST_PRAGMA_GCC_WARN_PUSH			IUTEST_PRAGMA_CLANG_WARN_PUSH
 #  define IUTEST_PRAGMA_GCC_WARN_DISABLE		IUTEST_PRAGMA_CLANG_WARN_DISABLE
 #  define IUTEST_PRAGMA_GCC_WARN_POP			IUTEST_PRAGMA_CLANG_WARN_POP
 #endif
 
-#ifndef IUTEST_PRAGMA_GCC_WARN_PUSH
+#if !defined(IUTEST_PRAGMA_MSC_WARN_PUSH)
+#  define IUTEST_PRAGMA_MSC_WARN_PUSH()
+#endif
+#if !defined(IUTEST_PRAGMA_MSC_WARN_DISABLE)
+#  define IUTEST_PRAGMA_MSC_WARN_DISABLE(x)
+#endif
+#if !defined(IUTEST_PRAGMA_MSC_WARN_POP)
+#  define IUTEST_PRAGMA_MSC_WARN_POP()
+#endif
+
+#if !defined(IUTEST_PRAGMA_GCC_WARN_PUSH)
 #  define IUTEST_PRAGMA_GCC_WARN_PUSH()
 #endif
-#ifndef IUTEST_PRAGMA_GCC_WARN_DISABLE
+#if !defined(IUTEST_PRAGMA_GCC_WARN_DISABLE)
 #  define IUTEST_PRAGMA_GCC_WARN_DISABLE(x)
 #endif
-#ifndef IUTEST_PRAGMA_GCC_WARN_POP
+#if !defined(IUTEST_PRAGMA_GCC_WARN_POP)
 #  define IUTEST_PRAGMA_GCC_WARN_POP()
 #endif
 
-#ifndef IUTEST_PRAGMA_CLANG_WARN_PUSH
+#if !defined(IUTEST_PRAGMA_CLANG_WARN_PUSH)
 #  define IUTEST_PRAGMA_CLANG_WARN_PUSH()
 #endif
-#ifndef IUTEST_PRAGMA_CLANG_WARN_DISABLE
+#if !defined(IUTEST_PRAGMA_CLANG_WARN_DISABLE)
 #  define IUTEST_PRAGMA_CLANG_WARN_DISABLE(x)
 #endif
-#ifndef IUTEST_PRAGMA_CLANG_WARN_POP
+#if !defined(IUTEST_PRAGMA_CLANG_WARN_POP)
 #  define IUTEST_PRAGMA_CLANG_WARN_POP()
 #endif
 
@@ -91,11 +110,11 @@
 #endif
 
 
-// pragma warning xxx
+/* pragma warning xxx */
 #if defined(_MSC_VER) && defined(__STDC_WANT_SECURE_LIB__) && __STDC_WANT_SECURE_LIB__
-#  define IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_BEGIN()		IUTEST_PRAGMA(warning (push))	\
-															IUTEST_PRAGMA(warning (disable:4996))
-#  define IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_END()		IUTEST_PRAGMA(warning (pop))
+#  define IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_BEGIN()		IUTEST_PRAGMA_MSC_WARN_PUSH()	\
+															IUTEST_PRAGMA_MSC_WARN_DISABLE(4996)
+#  define IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_END()		IUTEST_PRAGMA_MSC_WARN_POP()
 #else
 #  define IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_BEGIN()
 #  define IUTEST_PRAGMA_CRT_SECURE_WARN_DISABLE_END()
