@@ -2,20 +2,18 @@
 ----------------------------------------------------------------------*/
 /**
  * @file		iutest_static_assertion_c.h
- * @brief		iris unit test static assertion ` t@C
+ * @brief		iris unit test static assertion
  *
  * @author		t.sirayanagi
- * @version		1.0
- *
  * @par			copyright
- * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 /*----------------------------------------------------------------------
 ======================================================================*/
-#ifndef INCG_IRIS_iutest_static_assertion_C_H_53842FD6_9E5D_40a6_905D_EC6DEBE5ED6A_
-#define INCG_IRIS_iutest_static_assertion_C_H_53842FD6_9E5D_40a6_905D_EC6DEBE5ED6A_
+#ifndef INCG_IRIS_IUTEST_STATIC_ASSERTION_C_H_53842FD6_9E5D_40A6_905D_EC6DEBE5ED6A_
+#define INCG_IRIS_IUTEST_STATIC_ASSERTION_C_H_53842FD6_9E5D_40A6_905D_EC6DEBE5ED6A_
 
 /* define ============================================================*/
 /**
@@ -33,4 +31,18 @@
 #  define IUTEST_STATIC_ASSERT(...)		IUTEST_STATIC_ASSERT_MSG((__VA_ARGS__), "")
 #endif
 
+#ifdef IUTEST_HAS_COUNTER_MACRO
+#ifdef IUTEST_NO_VARIADIC_MACROS
+#  define IUTEST_PP_STATIC_ASSERT(B)	IUTEST_STATIC_ASSERT_MSG(B, "")
+#else
+#  define IUTEST_PP_STATIC_ASSERT(...)	IUTEST_STATIC_ASSERT_MSG((__VA_ARGS__), "")
+#endif
+#else
+#ifdef IUTEST_NO_VARIADIC_MACROS
+#  define IUTEST_PP_STATIC_ASSERT(B)	
+#else
+#  define IUTEST_PP_STATIC_ASSERT(...)	
+#endif
+#endif
+
 #endif
