@@ -5,11 +5,9 @@
  * @brief		iutest fixture test
  *
  * @author		t.sirayanagi
- * @version		1.0
- *
  * @par			copyright
- * Copyright (C) 2012-2013, Takazumi Shirayanagi\n
- * The new BSD License is applied to this software.
+ * Copyright (C) 2012-2015, Takazumi Shirayanagi\n
+ * This software is released under the new BSD License,
  * see LICENSE
 */
 /*----------------------------------------------------------------------
@@ -21,9 +19,17 @@
 int TestFixed_x = 0;
 int TestFixed_y = 0;
 
-void TestFixed_SetUp(void)
+void TestFixed_SetUp(iuTestInfo* test_info)
 {
+	IUTEST_UNUSED_VAR(test_info);
 	++TestFixed_x;
+	IUTEST_EXPECT_NE(TestFixed_y, TestFixed_x);
+}
+
+void TestFixed_TearDown(iuTestInfo* test_info)
+{
+	IUTEST_UNUSED_VAR(test_info);
+	IUTEST_EXPECT_EQ(TestFixed_y, TestFixed_x);
 }
 
 void TestFixed_SetUpTestCase(void)
@@ -32,11 +38,17 @@ void TestFixed_SetUpTestCase(void)
 	TestFixed_y = 0;
 }
 
+void TestFixed_TearDownTestCase(void)
+{
+	IUTEST_EXPECT_EQ(2, TestFixed_x);
+	IUTEST_EXPECT_EQ(2, TestFixed_y);
+}
+
 iuTestFixture TestFixed = {
 	TestFixed_SetUpTestCase
-	, NULL
+	, TestFixed_TearDownTestCase
 	, TestFixed_SetUp
-	, NULL
+	, TestFixed_TearDown
 	, NULL
 };
 
