@@ -6,7 +6,7 @@
  *
  * @author		t.sirayanagi
  * @par			copyright
- * Copyright (C) 2012-2014, Takazumi Shirayanagi\n
+ * Copyright (C) 2012-2015, Takazumi Shirayanagi\n
  * This software is released under the new BSD License,
  * see LICENSE
 */
@@ -19,8 +19,9 @@
 #if IUTEST_C_HAS_PARAM_METHOD_TEST
 
 static int s_parammethod_test_called = 0;
-static void ParamMethodTestFixed_SetUp(void)
+static void ParamMethodTestFixed_SetUp(iuTestInfo* test_info)
 {
+	IUTEST_UNUSED_VAR(test_info);
 	s_parammethod_test_called = 1;
 }
 
